icsemantic.catalog.indexes.translation.TranslationIndex

Package platecom :: Package ontocatalog :: Package indexes :: Module translation :: Class TranslationIndex |
[hide private]
[frames] | no frames]

# Class TranslationIndex

source code

           Globals.Persistent --+
                                |
    OFS.SimpleItem.SimpleItem --+
                                |
                               TranslationIndex

An index for translations that does not index anything

Instance Methods | [hide private]
__init__(self, id, extra=None, caller=None) Creates a new index | source code
index_object(self, docid, obj, threshold=100) Hook for (Z)Catalog. | source code
unindex_object(self, docid) Hook for (Z)Catalog. | source code
_apply_index(self, request, cid='') Apply the index to query parameters given in the argument, request. | source code

Class Variables | [hide private]
| __implements__ = `PluggableIndex.PluggableIndexInterface,`
| meta_type = `"TranslationIndex"`
| manage_workspace = `DTMLFile('dtml/manageFakeIndex', globals())`

Method Details | [hide private]

### index_object(self, docid, obj, threshold=100) | source code
Hook for (Z)Catalog. Since this is a fake index, nothing is done here.

### unindex_object(self, docid) | source code
Hook for (Z)Catalog. Since this is a fake index, nothing is done here.

### _apply_index(self, request, cid='') | source code
Apply the index to query parameters given in the argument, request. The argument should be a mapping object. If the request does not contain the needed parameters, then None is returned. Otherwise two objects are returned. The first object is a ResultSet containing the record numbers of the matching records. The second object is a tuple containing the names of all data fields used.